Support
================

If you are stuck with a problem using Hist, please do get in touch at our
`Issues <https://github.com/scikit-hep/hist/issues>`_ or `Gitter Channel
<https://gitter.im/HSF/PyHEP-histogramming>`_. The developers are willing to
help.

You can save time by following this procedure when reporting a problem:

* Do try to solve the problem on your own first. Read the documentation,
  including using the search feature, index and reference documentation.
* Search the issue archives to see if someone else already had the same
  problem.
* Before writing, try to create a minimal example that reproduces
  the problem. You'll get the fastest response if you can send just a handful
  of lines of code that show what isn't working.
